pub enum TransactionDriverError {
ClientInternal {
error: String,
},
ValidationFailed {
error: String,
},
Aborted {
submission_non_retriable_errors: AggregatedRequestErrors,
submission_retriable_errors: AggregatedRequestErrors,
observed_effects_digests: AggregatedEffectsDigests,
},
RejectedByValidators {
submission_non_retriable_errors: AggregatedRequestErrors,
submission_retriable_errors: AggregatedRequestErrors,
},
ForkedExecution {
observed_effects_digests: AggregatedEffectsDigests,
submission_non_retriable_errors: AggregatedRequestErrors,
submission_retriable_errors: AggregatedRequestErrors,
},
TimeoutWithLastRetriableError {
last_error: Option<Box<TransactionDriverError>>,
attempts: u32,
timeout: Duration,
},
}Expand description
Exports Client facing errors on transaction processing via Transaction Driver.
NOTE: every error should indicate if it is retriable.
Variants
ClientInternal
TransactionDriver encountered an internal error. Non-retriable.
ValidationFailed
The transaction failed validation from local state. Non-retriable.
Aborted
Transient failure during transaction processing that prevents the transaction from finalization. Retriable with new transaction submission.
Fields
submission_non_retriable_errors: AggregatedRequestErrorssubmission_retriable_errors: AggregatedRequestErrorsobserved_effects_digests: AggregatedEffectsDigestsRejectedByValidators
Over validity threshold of validators rejected the transaction as invalid. Non-retriable.
Fields
submission_non_retriable_errors: AggregatedRequestErrorssubmission_retriable_errors: AggregatedRequestErrorsForkedExecution
Transaction execution observed multiple effects digests, and it is no longer possible to certify any of them. Non-retriable.
Fields
observed_effects_digests: AggregatedEffectsDigestssubmission_non_retriable_errors: AggregatedRequestErrorssubmission_retriable_errors: AggregatedRequestErrorsTimeoutWithLastRetriableError
Transaction timed out but we return last retriable error if it exists. Non-retriable.
Implementations
Sourceimpl TransactionDriverError
impl TransactionDriverError
pub fn categorize(&self) -> ErrorCategory